@@ -7,9 +7,11 @@ sentry_wechat.models
 :copyright: (c) 2020 by cxt, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
-
+import sys
+reload(sys)
+sys.setdefaultencoding( "utf-8" )
 import json
-import grequests
+import requests
 from datetime import datetime
 from pytz import timezone
 
@@ -76,15 +78,15 @@ class WechatPlugin(NotificationPlugin):
         title = "[{}]发生错误，请尽快查看处理!".format(event.project.slug)
         description = event.title or event.message
         url="{}events/{}/".format(group.get_absolute_url(),event.event_id)
-
+        blank = "无"
         data = {
           "msgtype": "news",
                 "news": {
                 "articles" : [
                         {
-                            "title" : title or "",
-                            "url" : url or "",
-                            "description" : description or "",
+                            "title" : title or blank,
+                            "url" : url or blank,
+                            "description" : description or blank,
                             "picurl" : "https://i.loli.net/2020/04/28/xZqCELKHhBSeY9t.png"
                         }
                     ]
@@ -96,23 +98,21 @@ class WechatPlugin(NotificationPlugin):
                 "markdown": {
                     "content": u"#### {title} \n > 环境: <font color=\"info\">{environment}</font> \n > 等级: <font color=\"warning\">{level}</font> \n > 版本: <font color=\"comment\">{release}</font> \n > 浏览器: <font color=\"comment\">{browser}</font> \n > 操作系统: <font color=\"comment\">{os}</font> \n > 域名: <font color=\"comment\">{domain}</font> \n > 用户: <font color=\"comment\">{user}</font> \n > 报错信息: <font color=\"comment\">{message}</font> \n > 触发点: <font color=\"comment\">{culprit}</font> \n > 创建日期: <font color=\"comment\">{dateCreated}</font> \n > [怼我看BUG!]({url})".format(
                         title="详情",
-                        environment=event.get_tag("environment") or "",
-                        level=event.get_tag("level") or "",
-                        release=event.get_tag("release") or "",
-                        browser=event.get_tag("browser") or "",
-                        os=event.get_tag("os") or "",
-                        domain=event.get_tag("url") or "",
-                        user=event.get_tag("user") or "",
-                        message=description or "",
-                        culprit=event.culprit or "",
-                        dateCreated=datetime.now(timezone('Asia/Shanghai')).strftime("%Y-%m-%d %H:%M:%S") or "",
-                        url=url or "",
+                        environment=event.get_tag("environment") or blank,
+                        level=event.get_tag("level") or blank,
+                        release=event.get_tag("release") or blank,
+                        browser=event.get_tag("browser") or blank,
+                        os=event.get_tag("os") or blank,
+                        domain=event.get_tag("url") or blank,
+                        user=event.get_tag("user") or blank,
+                        message=description or blank,
+                        culprit=event.culprit or blank,
+                        dateCreated=datetime.now(timezone('Asia/Shanghai')).strftime("%Y-%m-%d %H:%M:%S") or blank,
+                        url=url or blank,
                     )
                 }
         }
 
-        req_list = [   # 请求列表
-            grequests.post(send_url,headers={"Content-Type": "application/json"},data=json.dumps(data)),
-            grequests.post(send_url,headers={"Content-Type": "application/json"},data=json.dumps(main_data)),
-        ]
-        grequests.map(req_list)
\ No newline at end of file
+        req_list = [data,main_data]
+        for val in req_list:
+            requests.post(url=send_url,headers={"Content-Type": "application/json"},data=json.dumps(val)),
\ No newline at end of file
